@@ -5,6 +5,7 @@
 #    Copyright (C) 2000, Yannick LE NY <y-le-ny@ifrance.com>
 #    Copyright (C) 2000, Paul Fenwick <pjf@cpan.org>
 #    Copyright (C) 2000, Brent Neal <brentn@users.sourceforge.net>
+#    Copyright (C) 2020, Caleb Begly <calebbegly@gmail.com>
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -18,8 +19,8 @@
 #
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-#    02111-1307, USA
+#    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+#    02110-1301, USA
 #
 #
 # This code derived from Padzensky's work on package Finance::YahooQuote,
@@ -36,9 +37,12 @@ use vars qw/$FIDELITY_URL /;
 use LWP::UserAgent;
 use HTTP::Request::Common;
 
-our $VERSION = '1.22'; # TRIAL VERSION
+use constant DEBUG => $ENV{DEBUG};
+use if DEBUG, 'Smart::Comments';
 
-$FIDELITY_URL = ("http://activequote.fidelity.com/nav/fulllist.csv");
+our $VERSION = '1.50'; # TRIAL VERSION
+
+$FIDELITY_URL = ("https://fundresearch.fidelity.com/mutual-funds/fidelity-funds-daily-pricing-yields/download");
 
 sub methods {return (fidelity        => \&fidelity,
                      fidelity_direct => \&fidelity);}
@@ -74,29 +78,30 @@ sub fidelity
     if ($reply->is_success) {
       foreach (split('\015?\012',$reply->content)) {
 	my @q = $quoter->parse_csv($_) or next;
-
-	$sym = $q[2] or next;
+	
+	$sym = $q[1] or next;
 	$sym =~ s/^ +//;
 
     	# Skip symbols we didn't ask for.
     	next unless (defined($symbolhash{$sym}));
 
+        ### q : @q
+
 	 $aa {$sym, "exchange"}	= "Fidelity";  # Fidelity
 	 $aa {$sym, "method"}  	= "fidelity_direct";
 	($aa {$sym, "name"}    	= $q[0]) =~ s/^\s+//;
 	 $aa {$sym, "name"}    	=~ s/\s+$//;
 	 $aa {$sym, "symbol"}  	= $sym;
-	($aa {$sym, "number"}  	= $q[1]) =~ s/^\s+//;
-	($aa {$sym, "nav"}     	= $q[4]) =~ s/^\s+// 	if defined($q[4]);
-	($aa {$sym, "div"}     	= $q[5]) =~ s/^\s+// 	if defined($q[5]);
-	($aa {$sym, "net"}     	= $q[6]) =~ s/^\s+// 	if defined($q[6]);
-	($aa {$sym, "p_change"} = $q[8]) =~ s/^\s+// 	if defined($q[8]);
-	($aa {$sym, "yield"}    = $q[9]) =~ s/^\s+// 	if defined($q[9]);
-	($aa {$sym, "yield"}    = $q[17]) =~ s/^\s+// 	if defined($q[17]);
-	 $aa {$sym, "price"}    = $aa{$sym, "nav"} 	if defined($q[4]);
+	($aa {$sym, "nav"}     	= $q[2]) =~ s/^\s+// 	if defined($q[2]);
+	($aa {$sym, "div"}     	= $q[3]) =~ s/^\s+// 	if defined($q[3]);
+	($aa {$sym, "p_change"} = $q[5]) =~ s/^\s+// 	if defined($q[5]);
+	($aa {$sym, "yield"}    = $q[6]) =~ s/^\s+// 	if defined($q[6]);
+	($aa {$sym, "yield"}    = $q[7]) =~ s/^\s+// 	if defined($q[7]);
+	($aa {$sym, "yield"}    = $q[8]) =~ s/^\s+// 	if defined($q[8]);
+	 $aa {$sym, "price"}    = $aa{$sym, "nav"} 	if defined($q[2]);
 	 $aa {$sym, "success"}  = 1;
 	 $aa {$sym, "currency"} = "USD";
-	 $quoter->store_date(\%aa, $sym, {usdate => $q[19]});
+	 $quoter->store_date(\%aa, $sym, {usdate => $q[12]});
       }
     }
 
@@ -111,10 +116,6 @@ sub fidelity
 
 Finance::Quote::Fidelity - Obtain information from Fidelity Investments.
 
-=head1 NOTE NOTE NOTE NOTE NOTE
-
-This module is currently non-functional.
-
 =head1 SYNOPSIS
 
     use Finance::Quote;
@@ -142,12 +143,10 @@ Investment's terms and conditions.
 =head1 LABELS RETURNED
 
 The following labels may be returned by Finance::Quote::Fidelity:
-exchange, name, number, nav, change, ask, date, yield, price.
+exchange, name, nav, p_change, date, yield, price.
 
 =head1 SEE ALSO
 
 Fidelity Investments, http://www.fidelity.com/
 
-Finance::Quote::Yahoo::USA;
-
 =cut
