@@ -3,10 +3,12 @@
 # Version 0.1 preliminary version using Cdnfundlibrary.pm v0.4 as an example
 
 package Finance::Quote::IndiaMutual;
-require 5.004;
 
 use strict;
 
+use constant DEBUG => $ENV{DEBUG};
+use if DEBUG, 'Smart::Comments';
+
 use vars qw( $AMFI_URL $AMFI_NAV_LIST $AMFI_MAIN_URL);
 
 use LWP::UserAgent;
@@ -14,26 +16,24 @@ use HTTP::Request::Common;
 use HTTP::Status;
 use HTML::TableExtract;
 
-our $VERSION = '1.22'; # TRIAL VERSION
+our $VERSION = '1.50'; # TRIAL VERSION
 
 # URLs of where to obtain information.
 
-#$AMFI_MAIN_URL = ("http://localhost/");
 $AMFI_MAIN_URL = ("http://www.amfiindia.com/");
-$AMFI_URL = ("${AMFI_MAIN_URL}NavReport.aspx?type=0");
-#$AMFI_URL = ("${AMFI_MAIN_URL}spages/NAV0.txt"); #This page seems to do the job also. Keep for reference
+$AMFI_URL = ("https://www.amfiindia.com/spages/NAVAll.txt");
 
 # amfinavlist.txt is a cache-file. keep it until updated on the website since this is a 1meg file.
 my $cachedir = $ENV{TMPDIR} // $ENV{TEMP} // '/tmp/';
 $AMFI_NAV_LIST = $cachedir."amfinavlist.txt";
 
 sub methods { return (indiamutual => \&amfiindia,
-		      amfiindia => \&amfiindia); }
+                      amfiindia => \&amfiindia); }
 
 {
     my @labels = qw/method source link name currency date isodate nav rprice sprice/;
     sub labels { return (indiamutual => \@labels,
-			 amfiindia => \@labels); }
+                         amfiindia => \@labels); }
 }
 
 #
@@ -49,56 +49,74 @@ sub amfiindia   {
     return unless @symbols;
 
     # Local Variables
-    my(%fundquote, %allquotes);
+    my %fundquote;
     my($ua, $url, $reply);
 
     $ua = $quoter->user_agent;
 
     $url = "$AMFI_URL";
 
+    ### cache : $AMFI_NAV_LIST
+  
     $reply = $ua->mirror($url, $AMFI_NAV_LIST);
 
     # Make sure something is returned
     unless ($reply->is_success or $reply->code == RC_NOT_MODIFIED) {
-	foreach my $symbol (@symbols) {
-	    $fundquote{$symbol,"success"} = 0;
-	    $fundquote{$symbol,"errormsg"} = "HTTP failure";
-	}
-	return wantarray ? %fundquote : \%fundquote;
+    foreach my $symbol (@symbols) {
+        $fundquote{$symbol,"success"} = 0;
+        $fundquote{$symbol,"errormsg"} = "HTTP failure";
+    }
+    return wantarray ? %fundquote : \%fundquote;
     }
 
+    my $nav_fh;
+    open $nav_fh, '<', $AMFI_NAV_LIST or die "Unexpected error in opening file: $!\n";
 
-    open NAV, $AMFI_NAV_LIST or die "Unexpected error in opening file: $!\n";
-
-    # Scheme Code;Scheme Name;Net Asset Value;Repurchase Price;Sale Price;Date
-    while (<NAV>) {
-	next if !/\;/;
-	chomp;
-	s/\r//;
-        my ($symbol, @data) = split /\s*\;\s*/;
-	$allquotes{$symbol} = \@data;
+    # Create a hash of all stocks requested
+    my %symbolhash;
+    foreach my $symbol (@symbols)
+    {
+        $symbolhash{$symbol} = 0;
     }
-    close(NAV);
+    my $csvhead;
+    my @headhash;
+
+    #Scheme Code;ISIN Div Payout/ ISIN Growth;ISIN Div Reinvestment;Scheme Name;Net Asset Value;Date
+    while (<$nav_fh>) {
+    next if !/\;/;
+    chomp;
+    s/\r//;
+        my ($symbol1, $symbol2, $symbol3, $name, $nav, $date) = split /\s*\;\s*/;
+    my $symbol;
+    if (exists $symbolhash{$symbol1}) {
+        $symbol = $symbol1;
+    }
+    elsif(exists $symbolhash{$symbol2}) {
+        $symbol = $symbol2;
+    }
+    elsif(exists $symbolhash{$symbol3}) {
+        $symbol = $symbol3;
+    }
+    else {
+        next;
+    }
+    $fundquote{$symbol, "symbol"} = $symbol;
+    $fundquote{$symbol, "currency"} = "INR";
+    $fundquote{$symbol, "source"} = $AMFI_MAIN_URL;
+    $fundquote{$symbol, "link"} = $url;
+    $fundquote{$symbol, "method"} = "amfiindia";
+    $fundquote{$symbol, "name"} = $name;
+    $fundquote{$symbol, "nav"} = $nav;
+    $quoter->store_date(\%fundquote, $symbol, {eurodate => $date});
+    $fundquote{$symbol, "success"} = 1;
+    }
+    close($nav_fh);
 
     foreach my $symbol (@symbols) {
-        $fundquote{$symbol, "symbol"} = $symbol;
-        $fundquote{$symbol, "currency"} = "INR";
-	$fundquote{$symbol, "source"} = $AMFI_MAIN_URL;
-	$fundquote{$symbol, "link"} = $url;
-	$fundquote{$symbol, "method"} = "amfitable";
-
-	my $data = $allquotes{$symbol};
-	if ($data) {
-            $fundquote{$symbol, "name"} = $data->[4];
-            $fundquote{$symbol, "nav"} = $data->[5];
-            $fundquote{$symbol, "rprice"} = $data->[6];
-            $fundquote{$symbol, "sprice"} = $data->[7];
-            $quoter->store_date(\%fundquote, $symbol, {eurodate => $data->[8]});
-            $fundquote{$symbol, "success"} = 1;
-	} else {
-	    $fundquote{$symbol, "success"} = 0;
-	    $fundquote{$symbol, "errormsg"} = "Fund not found";
-	}
+    unless (exists $fundquote{$symbol, 'success'}) {
+            $fundquote{$symbol, 'success'} = 0;
+            $fundquote{$symbol, 'errormsg'} = 'Fund not found.';
+        }
     }
 
     return wantarray ? %fundquote : \%fundquote;
@@ -131,13 +149,11 @@ The information source "indiamutual" can be used
 if the source of prices is irrelevant, and "amfiindia" if you
 specifically want to use information downloaded from amfiindia.com.
 
-=head1 AMFIINDIA-CODE
+=head1 AMFIINDIA-CODE/ISIN
 
-In India a mutual fund does not have a unique global symbol identifier.
-
-This module uses an id that represents the mutual fund on an id used by
-amfiindia.com.  You can the fund is from the AMFI web site
-http://amfiindia.com/downloadnavopen.asp.
+In India, not all funds have an ISIN. However, they do have a scheme code.
+You can use those if you can't find the ISIN. See AMFI site for details.
+http://www.amfiindia.com/nav-history-download
 
 =head1 LABELS RETURNED
 
@@ -148,15 +164,13 @@ label will be a url location for the NAV list table for all funds.
 
 =head1 NOTES
 
-amfiindia.com provides a link to download a text file containing all the
+AMFI provides a link to download a text file containing all the
 NAVs. This file is mirrored in a local file /tmp/amfinavlist.txt. The local
 mirror serves only as a cache and can be safely removed.
 
-Currently NAVs of Open-Ended funds are supported.
-
 =head1 SEE ALSO
 
-AMFI india website - http://amfiindia.com/
+AMFI india website - http://www.amfiindia.com/
 
 Finance::Quote
 
