@@ -23,24 +23,24 @@ require 5.006;
 use strict;
 use warnings;
 use base 'Exporter';
-use Date::Calc qw(Add_Delta_Days Today);
+use DateTime;
 
 use vars qw( $MORNINGSTAR_JP_URL);
 
 our @EXPORT_OK = qw(morningstarjp methods labels);
-our $VERSION = '1.22'; # TRIAL VERSION
+our $VERSION = '1.50'; # TRIAL VERSION
 
 # NAV information (basis price)
 $MORNINGSTAR_JP_URL =
-  ('http://www.morningstar.co.jp/FundData/DownloadStdYmd.do?fnc=');
+  ('https://www.morningstar.co.jp/FundData/DownloadStdYmd.do?fnc=');
 
 sub methods { return ( morningstarjp => \&morningstarjp ); }
 sub labels  { return ( morningstarjp => [qw/symbol date nav/] ); }
 
 sub morningstarjp
 {
-  my @symbols = @_;
   my $quoter  = shift;
+  my @symbols = @_;
 
   my (
        $ua,    $response, %info,   $date,    $nav,   $year,
@@ -49,16 +49,21 @@ sub morningstarjp
 
   $ua = $quoter->user_agent;
 
+  # calculate beginning and end date
+  # Starting from 10 days prior (to cover any recent holiday gaps)
+
+  my $calcDay = DateTime->now();
+  $year  = $calcDay->year();
+  $month = $calcDay->month();
+  $day   = $calcDay->day();
+  $calcDay->subtract( days => 10 );
+  $fmyear  = $calcDay->year();
+  $fmmonth = $calcDay->month();
+  $fmday   = $calcDay->day();
+
 # Iterate over each symbol as site only permits query by single security
   foreach my $symbol (@symbols)
   {
-
-    # Search upto and including today
-    ( $year, $month, $day ) = Today();
-
-    # Starting from 10 days prior (to cover any recent holiday gaps)
-    ( $fmyear, $fmmonth, $fmday ) = Add_Delta_Days( $year, $month, $day, -10 );
-
     # Query the server via a POST request
     $response = $ua->post(
       $MORNINGSTAR_JP_URL . $symbol,
