@@ -20,8 +20,8 @@
 #
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-#    02111-1307, USA
+#    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+#    02110-1301, USA
 #
 #
 # This code derived from Padzensky's work on package Finance::YahooQuote,
@@ -38,7 +38,7 @@ use strict;
 use LWP::UserAgent;
 use HTTP::Request::Common;
 
-our $VERSION = '1.22'; # TRIAL VERSION
+our $VERSION = '1.50'; # TRIAL VERSION
 
 sub methods { return (unionfunds => \&unionfunds); }
 sub labels { return (unionfunds => [qw/exchange name date isodate price method/]); }
@@ -128,7 +128,7 @@ sub unionfunds
 
 sub unionurl
 {
-  return "http://www.union-invest.de/preise.csv";
+  return "https://www.union-investment.de/preise.csv";
 }
 
 1;
